# max_ard

A Python SDK and CLI for working with [Maxar ARD Imagery](https://ard.maxar.com/docs/)

## Introduction

`max_ard` consists of a Python SDK for selecting, ordering, and working with Maxar ARD imagery and a set of CLI tools for common tasks.

## Installation

`pip install max-ard`

## Documentation

Extensive docs are available at https://ard.maxar.com/docs/sdk/
